clear
global root = "USE_YOUR_ROOT"

use "${root}/data/esee_Y_long.dta", clear

/* drops quadrienal variables which were collected both in 1990 and 1991 and uses solely the 1991 ones */
	drop PSEVT SF CAD RB SSF MHCN

/* Merge variables collected in 1990 and then replaced by similar variable in 1991 but with different code */
	replace CR41N=CR41 if YEAR==1990
	replace CR42N=CR42 if YEAR==1990
	replace CR4PN=CR4P if YEAR==1990
	replace CI1N=CI1 if YEAR==1990
	replace CI2N=CI2 if YEAR==1990
	replace CPMN=CPM if YEAR==1990
	replace ECM1N=ECM1 if YEAR==1990
	replace ECM2N=ECM2 if YEAR==1990
	replace HEXN=HEX if YEAR==1990
	replace HNOTN=HNOT if YEAR==1990
	replace IDMERPN=IDMERP if YEAR==1990
	replace IECMN=IECM if YEAR==1990
	replace M1VPV1=MVPV1 if YEAR==1990
	replace M1VPV2=MVPV2 if YEAR==1990
	replace NCM1N=NCM1 if YEAR==1990
	replace NCM2N=NCM2 if YEAR==1990
	replace DM1N=DM1 if YEAR==1990
	replace DM2N=DM2 if YEAR==1990

drop CR41 CR42 CR4P CI1 CI2 CPM ECM1 ECM2 HEX HNOT IDMERP IECM MVPV1 MVPV2 NCM1 NCM2 DM1 DM2
	
so ORDINAL YEAR
drop _merge
merge ORDINAL YEAR using "${root}/Data/esee_Q_long_full.dta", unique

so ORDINAL YEAR
by ORDINAL: replace NACECLIO=L.NACECLIO if L.NACECLIO!=. & NACECLIO==.

so NACECLIO
drop _merge
merge NACECLIO using "${root}/Data/NACECLIO.dta", uniqusing
so ORDINAL YEAR
drop _merge
so NACECLIO YEAR
merge NACECLIO YEAR using "${root}/Data/industry_def_nace2.dta", uniqusing
so ORDINAL YEAR
gen dVA_def=VA_def/L.VA_def-1

/* GENERATE NEW STATUS VARIABLE FROM IDMOV AND CAMBIO */
gen STATUS=0 /* Shut down (permanent or temporary), no reporting, no manufacturing, no answer */
replace STATUS=1 if IDMOV==1 & CAMBIO==2 /* Acquired other firms */
replace STATUS=2 if IDMOV==1 & CAMBIO==4 /* Merged with other firms */
replace STATUS=3 if IDMOV==2 & CAMBIO==1 /* Splitted part of the firm */
replace STATUS=4 if IDMOV==2 & CAMBIO==3 /* Result of a spin off */
replace STATUS=4 if IDMOV==3 /* Result of a spin off */
replace STATUS=5 if IDMOV==4 /* Acquired by other firm, left industry */
replace STATUS=6 if IDMOV==5 /* No Changes */
gen FSTATUS=F.STATUS /* generates the variable that tells me the exit reason for the last observation+1 */

replace STATUS=1 if ORDINAL==987 & YEAR==2001 
replace STATUS=3 if ORDINAL==2145 & YEAR==2001 


gen checkdata=0
replace checkdata=1 if IDMOV==0
gen checkdata2=0
replace checkdata2=1 if l.VENTAS==. & VENTAS!=.
by ORDINAL: gen checkdata2sum=sum(checkdata2)
by ORDINAL: egen checkdata2max=max(checkdata2sum)
drop if IDMOV==. /* DROPS the first missing values before first reporting */
drop if checkdata2max==checkdata2sum & checkdata==1 & IDMOV==0 /* DROPS the last missing values after last reporting, BUT NOT INTERMEDIATE MISSING YEARS*/
drop if IDMOV==4 /* DROPS the last missing values after last reporting, BUT NOT INTERMEDIATE MISSING YEARS*/
/* drop if STATUS==0 | STATUS==5 THIS KEEPS ONLY OBSERVATIONS REPORTED AND DROPS INTERMEDIATE MISSING YEARS */
by ORDINAL: gen missing_intermediate=sum(checkdata)
drop checkdata*

/* Drop particular cases */
drop if ORDINAL==1334 & YEAR>1992
/* drop if YEAR==1990 DROPS FIRST YEAR DUE TO LOTS OF MISSING VARIABLES, INCLUDING CAPITAL STOCKS */
drop if YEAR==1990 & F.YEAR==. /* DROPS ALL FIRMS SOLELY OBSERVED IN THE FIRST YEAR */
drop if YEAR==1990 & ORDINAL==1028

/* Problems with founding year changes.... use first available year

by ORDINAL: gen AEMPaux=AEMP if YEAR==1990
by ORDINAL: egen AEMP90=mean(AEMPaux)
drop AEMPaux

by ORDINAL: gen AEMPaux=AEMP if YEAR==1994
by ORDINAL: egen AEMP94=mean(AEMPaux)
drop AEMPaux

by ORDINAL: gen AEMPaux=AEMP if YEAR==1998
by ORDINAL: egen AEMP98=mean(AEMPaux)
drop AEMPaux

by ORDINAL: gen AEMPaux=AEMP if YEAR==2002
by ORDINAL: egen AEMP02=mean(AEMPaux)
drop AEMPaux

by ORDINAL: gen AEMPaux=AEMP if YEAR==2006
by ORDINAL: egen AEMP06=mean(AEMPaux)
drop AEMPaux


l ORDINAL YEAR STATUS L.STATUS AEMP L.AEMP if AEMP90==AEMP98 & AEMP90!=AEMP94
l ORDINAL YEAR STATUS L.STATUS AEMP L.AEMP if AEMP94==AEMP02 & AEMP94!=AEMP98
l ORDINAL YEAR STATUS L.STATUS AEMP L.AEMP if AEMP98==AEMP06 & AEMP98!=AEMP02

gen AEMP_original=AEMP
replace AEMP=AEMP90 if AEMP90==AEMP98 & AEMP90!=AEMP94 & YEAR<1998
replace AEMP=AEMP94 if AEMP94==AEMP02 & AEMP94!=AEMP98 & YEAR<2002
replace AEMP=AEMP98 if AEMP98==AEMP06 & AEMP98!=AEMP02 & YEAR<2006

replace AEMP=AEMP90 if AEMP90==AEMP02 & (AEMP90!=AEMP94 | AEMP90!=AEMP98) & YEAR<2002
replace AEMP=AEMP94 if AEMP94==AEMP06 & (AEMP94!=AEMP98 | AEMP94!=AEMP02) & YEAR<2006

replace AEMP=AEMP90 if AEMP90==AEMP06 & (AEMP90!=AEMP94 | AEMP90!=AEMP98 | AEMP90!=AEMP02) & YEAR<2006



replace AEMP=AEMP90 if AEMP90==AEMP94+1 | AEMP90==AEMP94-1 | AEMP90==AEMP98+1 | AEMP90==AEMP98-1 | AEMP90==AEMP02+1 | AEMP90==AEMP02-1 | AEMP90==AEMP06+1 | AEMP90==AEMP06-1
replace AEMP=AEMP94 if AEMP94==AEMP98+1 | AEMP94==AEMP98-1 | AEMP94==AEMP02+1 | AEMP94==AEMP02-1 | AEMP94==AEMP06+1 | AEMP94==AEMP06-1
replace AEMP=AEMP98 if AEMP98==AEMP02+1 | AEMP98==AEMP02-1 | AEMP98==AEMP06+1 | AEMP98==AEMP06-1
replace AEMP=AEMP02 if AEMP02==AEMP06+1 | AEMP02==AEMP06-1


by ORDINAL: gen changeaux=1 if STATUS==2 | STATUS==3
by ORDINAL: egen changes=mean(changeaux)
clear changes changeaux

tab ORDINAL if AEMP_original!=L.AEMP_original & L.AEMP_original!=. & changes==1 */


gen FDYaux=AEMP if L.AEMP==. & AEMP!=.
replace FDYaux=YEAR if YEAR<FDYaux & FDYaux!=.
by ORDINAL: egen FDY=mean(FDYaux)

/* locate larger spans of reporting! */

	gen zeros=1 if STATUS==0
	by ORDINAL: egen sum0=sum(zeros)

	gen count=1 if STATUS==0 & L.STATUS!=0
	replace count=L.count+1 if STATUS==0 & L.STATUS==0
	
	gen count2=1 if STATUS!=0 & (L.STATUS==0 | L.STATUS==.)
	/* replace count2=1 if STATUS!=0 & YEAR==1990 */
	replace count2=L.count2+1 if STATUS!=0 & L.STATUS!=0 & L.STATUS!=.
	by ORDINAL: egen countmax=max(count2)
	
	gen ident=1 if count2==countmax
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0
	replace ident=F.ident if F.ident==1 & STATUS!=0

/* keeps only non-reporting for one year so that values can be generated by interpolation, for the other missing in the middle keeps the larger span*/ 

drop if ident==. & sum0>1 /* this drops all observations with more then 1 missing value and for which there is a larger reporting span */
/* DROP FIRMS WITH VERY IRREGULAR REPORTING PATTERNS, I.E., REPORT, STOP, REPORT, STOP, ... */
/* by ORDINAL: gen LY= Y[_n-1]+1
gen missing_int=1 if YEAR!=LY & LY!=. */
drop if ORDINAL==315 | ORDINAL==425 | ORDINAL==1548 | ORDINAL==1569 | ORDINAL==2012 | ORDINAL==2072 | ORDINAL==2194 | ORDINAL==2274 | ORDINAL==2872 | ORDINAL==3398 | ORDINAL==971 | ORDINAL==1819  | ORDINAL==2279 | ORDINAL==3266

drop missing_intermediate FDYaux zeros count sum0 count2 countmax ident
