First use IVIE data clean_arrange_merge_datasets.do followed by generate_variables.do

	
	/* Generate the aggregate demand shocks by regressing m_w on t dummies and controling for fixed effects */
		xtreg m_w YEAR i.YEAR, fe
		predict all_ind,xb
	/* Generate the averaged (over year) reported demand shocks */	
		bysort YEAR: egen mean_ag_mk_change=mean(mkt_change )
		
/* Figure - Input ratio vs. self reported demand conditions: whole manufacturing sector (left). */	
		twoway (tsline mean_ag_mk_change, lcolor(gs0) lpattern(solid) ) (tsline all_ind , yaxis(2)  lcolor(gs0) lpattern(dash)), legend(label(1 "Reported changes in Market Conditions") label(2 "Estimated Demand Shocks") cols(1)) ytitle("") scheme(s2mono) graphregion(fcolor(gs16))
		graph save Graph "${root}/figures/esee_tseries_demand_vs_estimates_allind.gph", replace
		graph export "${root}/figures/esee_tseries_demand_vs_estimates_allind.pdf", as(pdf) replace
		graph export "${root}/figures/esee_tseries_demand_vs_estimates_allind.tif", as(tif) replace


	/* Generate the aggregate demand shocks by regressing m_w on t dummies and controling for fixed effects */
		gen coef=0
		forvalues i = 1 (1) 20 {
		xtreg m_w YEAR i.YEAR if NACECLIO==`i', fe
		estimates store nace`i'
		forvalues t = 1991 (1) 2005 {
		replace coef=_b[`t'.YEAR] if NACECLIO==`i' & YEAR==`t'
		}
		}
	/* Generate the averaged (over industry and year) reported demand shocks */	
		bysort NACECLIO: egen mean_mk_change_nc=mean(mkt_change )
		bysort NACECLIO YEAR: egen mean_mk_change=mean(mkt_change-mean_mk_change_nc )
		
	/* plot the estimated aggregate demand shocks and the averaged (over industry and year) reported demand shocks */	
		so NACECLIO
		drop _merge
		merge m:1 NACECLIO using "${root}/Data/naceclio.dta"

/* Appendix Figure - Year-averaged estimated demand shocks and self-reported changes in market conditions, by industry. */
		twoway (line mean_mk_change YEAR, lcolor(gs0) lpattern(solid)) (line coef YEAR, lcolor(gs0) lpattern(dash)), by(, title(Time series plots of estimated demand shocks and averag self reported changes in market conditions by industry)) legend(order(1 - "Estimated Demand Shocks" 2 - "Reported changes in Market Conditions")) by(NACECLIO)  scheme(s2mono) graphregion(fcolor(gs16))
		replace INDUSTRY="Leather fur and footwear" if INDUSTRY=="Leather, fur and footwear"
		replace INDUSTRY="Office mach etc" if INDUSTRY=="Office mach., data proc., precision instr. and similar"
		local v=1
		foreach indna in "Basic metal products"	"Beverage"	"Chemicals"	"Electric materials and accessories"	"Fabricated metal products"	"Food and tobacco"	"Furniture"	"Industrial and agricultural equipment"	"Leather fur and footwear"	"Meat related products"	"Miscellaneous"	"Nonmetal mineral products"	"Office mach etc"	"Other transportation materials"	"Paper"	"Plastic and rubber products"	"Printing and publishing"	"Textiles and clothing"	"Timber"	"Vehicles and accessories"  {
			qui estpost sum mean_mk_change if INDUSTRY=="`indna'"
			mat minivar1 = e(max)
			local minpf = minivar1[1,1]
			qui estpost sum coef if INDUSTRY=="`indna'"
			mat minivar2 = e(min)
			local maxcost = minivar2[1,1]
			
			corr mean_mk_change coef if INDUSTRY=="`indna'"
			twoway (line mean_mk_change YEAR, lcolor(gs0) lpattern(solid)) (line coef YEAR, lcolor(gs0) lpattern(dash)) if INDUSTRY=="`indna'", legend(off) name(mkch_`v') text(`maxcost' 2003 "Corr=`=round(100*r(rho))'%", size(4)) title(`indna')  ytitle("") xtitle("")  scheme(s2mono) graphregion(fcolor(gs16))
			
			local v=`v'+1
		}
		replace INDUSTRY="Leather, fur and footwear" if INDUSTRY=="Leather fur and footwear"
		replace INDUSTRY="Office mach., data proc., precision instr. and similar" if INDUSTRY=="Office mach etc"

		gr combine mkch_1 mkch_2 mkch_3 mkch_4 mkch_5 mkch_6 mkch_7 mkch_8 mkch_9 mkch_10 mkch_11 mkch_12 mkch_13 mkch_14 mkch_15 mkch_16 mkch_17 mkch_18 mkch_19 mkch_20, b1title("-----(solid) - Reported changes in Market conditions"  "  "  "- - -(dashed) - Estimated Demand shocks", justification(left)) col(4)  scheme(s2mono) graphregion(fcolor(gs16))
		graph save Graph "${root}/figures/esee_tseries_demand_vs_estimates_byind.gph", replace
		graph export "${root}/figures/esee_tseries_demand_vs_estimates_byind.pdf", as(pdf) replace
		graph export "${root}/figures/esee_tseries_demand_vs_estimates_byind.tif", as(tif) replace
		graph drop _all

	
/* Figure - Input ratio vs. self reported demand conditions: whole manufacturing sector (right). */	

		twoway (lfit all_ind mean_ag_mk_change) (scatter all_ind mean_ag_mk_change), ytitle(Input ratio (detrended)) xtitle(Self-reported demand shocks) legend(off)  scheme(s2mono) graphregion(fcolor(gs16))
		graph save Graph "${root}/figures/inputratio_demand.gph", replace
		graph export "${root}/figures/inputratio_demand.pdf", as(pdf) replace
		graph export "${root}/figures/inputratio_demand.tif", as(tif) replace
		graph drop _all
	

	/* generate demand shocks cleaning log(M/W) from individual fixed effects (note we can add capital, labor or materials this way we are assuming cobb douglas. results do not chage)*/

		so ORDINAL YEAR
		xtreg m_w l.m_w, fe
		predict ed, e

		
/* Table - Moments of the estimated demand shock */

			sum ed /* standard error */
			
			pwcorr ed l.ed l2.ed l3.ed l4.ed l5.ed  /* serial correlation */
			
			/*cross sectional dependence */
			gen dum=1 
			replace dum=. if d.m_w==. 
			bysort ORDINAL: egen sdNACE=sd(NACECLIO)
			replace dum=. if sdNACE>0 & sdNACE!=.
			drop sdNACE
			bysort ORDINAL: egen nobs=sum(dum)
			so ORDINAL YEAR
			set matsize 5000
			xtreg ed  if nobs>9
			xtcsd, pesaran abs
			xtreg ed YEAR_*  if nobs>9, fe
			xtcsd, pesaran abs
		
/* Table  - Correlation of estimated estimated demand shocks with market conditions */
	
		forvalues i = 1 (1) 20 {
		reg ed mkt_change i.YEAR if NACECLIO==`i', vce(cluster ORDINAL)
/*		outreg2 using Table1a, excel `append' onecol ctitle(`NACECLIO') addtext(Firm FE, YES) title(demand shock estimates)*/
		estimates store naceedfea`i'
		reg ed mkt_share_change i.YEAR if NACECLIO==`i', vce(cluster ORDINAL)
		estimates store naceedfeb`i'
		reg ed mkt_change mkt_share_change i.YEAR if NACECLIO==`i', vce(cluster ORDINAL)
		estimates store naceedfec`i'
		/*xtserial ed mkt_change if NACECLIO==`i'
		outreg2 using Table1,  addstat("Wooldridge test for autocorrelation in panel data (pval)", r(p)) 
		xtreg ed mkt_change YEAR_* if NACECLIO==`i' & nobs>9, fe
		xtcsd, pesaran
		outreg2 using Table1b, excel `append' onecol ctitle(`NACECLIO') addtext(Firm FE, YES, Year dummies, YES) title(demand shock estimates) addstat("Pesaran's test of cross sectional independence (pval)", r(pesaran))*/
		}
		drop dum nobs
		/* Note: I use fixed effects but results are virtually unchanged without fixed effects */
		estimates table naceedfea* , b(%7.3f) star stats(N)
		estimates table naceedfeb* , b(%7.3f) star stats(N)
		estimates table naceedfec* , b(%7.3f) star stats(N)


		
/* Table - Test for serial correlation: Dynamic panel data (GMM) estimates. */
		xtdpd ed l.ed , dgmmiv(ed, lagrange(2 4)) vce(cluster ORDINAL) artests(3) twostep
		estat abond


		/* On the side estimate the production function & tfp */

			gen tfp=.
			forvalues i = 1 (1) 20 {
				xtreg qp kadj l mdef fsedef i.YEAR if NACECLIO==`i' & L>=10, fe vce(cluster ORDINAL)
				estimates store pffe`i'
				predict tfpres if NACECLIO==`i', ue
				replace tfp=tfpres if NACECLIO==`i'
				drop tfpres
			}

/* Appendix Table - Production Function Estimates, fixed effects by industry */			
			estimates table pffe*, b(%7.3f) star(0.05 0.01 0.001) stats(N)

			gen tfpr=.
			forvalues i = 1 (1) 20 {
				xtreg yp kadj l mdef i.YEAR if NACECLIO==`i', fe
				estimates store pffe`i'
				predict tfpres if NACECLIO==`i', ue
				replace tfpr=tfpres if NACECLIO==`i'
				drop tfpres
			}
		cd "${root}/Results/"

/* Table - Correlation of estimated demand and TFP with prices and quantities, by industry.*/

		reg qr i.NACECLIO#c.ed i.NACECLIO, vce(cluster ORDINAL)
		outreg2 using Table_pq, excel replace ctitle(`NACECLIO') side
		reg qr i.NACECLIO#c.D.tfp i.NACECLIO, vce(cluster ORDINAL)
		outreg2 using Table_pq, excel append ctitle(`NACECLIO') side
		reg lp_index i.NACECLIO#c.ed i.NACECLIO, vce(cluster ORDINAL)
		outreg2 using Table_pq, excel append ctitle(`NACECLIO') side
		reg lp_index i.NACECLIO#c.D.tfp i.NACECLIO, vce(cluster ORDINAL)
		outreg2 using Table_pq, excel append ctitle(`NACECLIO') side


		
/*  Table - Input demand equations (with estimated demand shocks) */

		
		/* First use the input ratio shocks */

			
				forvalues i = 1 (1) 20 {
					reg w ed kadj tfp YEAR_* if NACECLIO==`i', vce(cluster ORDINAL)
					estimates store wtest`i'
					reg m ed kadj tfp YEAR_* if NACECLIO==`i', vce(cluster ORDINAL)
					estimates store mtest`i'

				}
				estimates table wtest*, b(%7.3f) star(0.05 0.01 0.001) stats(N)
				estimates table mtest*, b(%7.3f) star(0.05 0.01 0.001) stats(N)
		
		/* Alternative use actual data of mkt_change */		

		
/*  Appendix Table - Input demand equations (with self reported demand shocks) */
			
			forvalues i = 1 (1) 20 {
				xtreg m mkt_change kadj tfp YEAR_* if NACECLIO==`i', fe  vce(cluster ORDINAL)
				estimates store nacem1`i'
				xtreg w mkt_change kadj tfp YEAR_* if NACECLIO==`i', fe  vce(cluster ORDINAL)
				estimates store nacew1`i'
			}
			estimates table nacew1*, b(%7.3f) star(0.05 0.01 0.001) stats(N)
			estimates table nacem1*, b(%7.3f) star(0.05 0.01 0.001) stats(N)

	/* Estimate the demand function & demand residuals under AR1 and endogenous prices */


	gen lage=ln(age)
	sum d.y if age>0 & age<5
	gen edshock=.
	gen edshockgmma=.
	gen edshockgmmb=.
	gen year1=0
	replace year1=1 if ORDINAL[_n-1]!=ORDINAL
	gen factor=(1.063^(1-age))*(1-1.063^age)/(1-1.063)
	gen stockZ=VENTAS*factor if year1==1 & age>0
	replace stockZ=L.stockZ+VENTAS if year1!=1
	gen lz=ln(stockZ)
	so ORDINAL YEAR
		gen sigma=.
		local append "replace"
		forvalues i = 1 (1) 20 {
		
		/* Estimate demand without instruments */
			gmm ( qr-({y3}+{y4}*YEAR_4+{y5}*YEAR_5+{y6}*YEAR_6+{y7}*YEAR_7+{y8}*YEAR_8+{y9}*YEAR_9+{y10}*YEAR_10+{y11}*YEAR_11+{y12}*YEAR_12+{y13}*YEAR_13+{y14}*YEAR_14+{y15}*YEAR_15+{y16}*YEAR_16+{y17}*YEAR_17+{betaq1}*lp_index+{betaage}*lage+{betalz}*lz+{ar1}*(l.qr-{betaq1}*l.lp_index-{betaage}*l.lage-{betalz}*l.lz))) if l.qr!=. & l.lp_index!=. & l.lage!=. & l.lz!=. & NACECLIO==`i' , instruments(qr lz lage tfp kadj l.qr l.lp_index l.tfp l.kadj l.lage l.lz YEAR_4 YEAR_5 YEAR_6 YEAR_7 YEAR_8 YEAR_9 YEAR_10  YEAR_11 YEAR_12 YEAR_13 YEAR_14 YEAR_15 YEAR_16 YEAR_17) vce(cluster ORDINAL)  from(y3 0 y4 0 y5 0 y6 0 y7 0 betaq1 -1 ar1 0.9)
			estimates store demandgmma`i'
			outreg2 using Table_demand_gmma,  excel `append' onecol ctitle(`i') title(GMM demand estimates)
			predict edsh
			replace edshockgmma=edsh if NACECLIO==`i'
			drop edsh 

		/* Estimate demand with instruments */
			
			gmm ( qr-({y3}+{y4}*YEAR_4+{y5}*YEAR_5+{y6}*YEAR_6+{y7}*YEAR_7+{y8}*YEAR_8+{y9}*YEAR_9+{y10}*YEAR_10+{y11}*YEAR_11+{y12}*YEAR_12+{y13}*YEAR_13+{y14}*YEAR_14+{y15}*YEAR_15+{y16}*YEAR_16+{y17}*YEAR_17+{betaq1}*lp_index+{betaage}*lage+{betalz}*lz+{ar1}*(l.qr-{betaq1}*l.lp_index-{betaage}*l.lage-{betalz}*l.lz))) if l.qr!=. & l.lp_index!=. & l.lage!=. & l.lz!=. & NACECLIO==`i' , instruments(lage tfp kadj l.qr l.lp_index l.tfp l.kadj l.lage l.lz YEAR_4 YEAR_5 YEAR_6 YEAR_7 YEAR_8 YEAR_9 YEAR_10  YEAR_11 YEAR_12 YEAR_13 YEAR_14 YEAR_15 YEAR_16 YEAR_17) vce(cluster ORDINAL)  from(y3 0 y4 0 y5 0 y6 0 y7 0 betaq1 -1 ar1 0.9)
			replace sigma=_b[betaq1:_cons] if NACECLIO==`i'
			estat overid
			estimates store demandgmmb`i'
			outreg2 using Table_demand_gmmb,  addstat("Overid test (pval)", r(J_p)) excel `append' onecol ctitle(`i') title(GMM demand estimates)
/*			if `first++'==1 local append append*/
			predict edsh
			replace edshockgmmb=edsh if NACECLIO==`i'
			drop edsh 
			local append "append"
		}

/* Appendix Table - Demand estimates, IV results per industry.*/

		estimates table demandgmmb*, b(%7.3f) star(0.05 0.01 0.001) stats(N)
		
	/* Table not reported - Illustrate the problem of endogeneity of prices by comparing demand estimates without tfp as instrument */
		estimates table demandgmma*, b(%7.3f) star(0.05 0.01 0.001) stats(N)

		/* Compare the two demand shocks */
		
/* Appendix Table - Correlation of the demand shock estimated via demand function with the self reported demand change and the demand shock estimated via input ratio. */
		forvalues i = 1 (1) 20 {
			reg ed edshockgmmb i.YEAR if NACECLIO==`i', vce(cluster ORDINAL)
			estimates store naceedfea`i'
			reg ed mkt_change edshockgmmb i.YEAR if NACECLIO==`i', vce(cluster ORDINAL)
			estimates store naceedfeb`i'
		}
		estimates table naceedfea* , b(%7.3f) star stats(N)
		estimates table naceedfeb* , b(%7.3f) star stats(N)

/*		
		replace INDUSTRY="Leather fur and footwear" if INDUSTRY=="Leather, fur and footwear"
		replace INDUSTRY="Office mach etc" if INDUSTRY=="Office mach., data proc., precision instr. and similar"
		replace edshockgmmb=(8/5)*edshockgmmb
		graph twoway (lfit ed edshockgmmb if abs(edshockgmmb)<1 & abs(ed)<1) (scatter ed edshockgmmb if abs(edshockgmmb)<1 & abs(ed)<1) if abs(edshockgmmb)<1 & abs(ed)<1, by(INDUSTRY, legend(off)) ytitle("Demand shock (Input ratio)") xtitle("Demand shock (demand function)")  scheme(s2mono) graphregion(fcolor(gs16))
		graph save Graph "${root}/figures/demand_compare.gph", replace
		graph export "${root}/figures/demand_compare.pdf", as(pdf) replace
		graph export "${root}/figures/demand_compare.tif", as(tif) replace
		replace INDUSTRY="Leather, fur and footwear" if INDUSTRY=="Leather fur and footwear"
		replace INDUSTRY="Office mach., data proc., precision instr. and similar" if INDUSTRY=="Office mach etc"
		
*/

/*  Appendix Table - Input demand equations (with estimated demand residuals) */

		forvalues i = 1 (1) 20 {
			reg w edshockgmmb kadj tfp YEAR_* if NACECLIO==`i', vce(cluster ORDINAL)
			estimates store wtest`i'
			reg m edshockgmmb kadj tfp YEAR_* if NACECLIO==`i', vce(cluster ORDINAL)
			estimates store mtest`i'
		}
		estimates table wtest*, b(%7.3f) star(0.05 0.01 0.001) stats(N)
		estimates table mtest*, b(%7.3f) star(0.05 0.01 0.001) stats(N)

			
		gen l_temp100=100*L_temp/L	
		gen l_hours_ext100=100*L_hours_ext/L_hours
		bysort ORDINAL: egen meanedshock=mean(edshockgmmb)
		bysort ORDINAL: egen meanmkt_change=mean(mkt_change)
		gen edshock_demean=edshockgmmb-meanedshock
		gen mkt_change_demean=mkt_change-meanmkt_change
		gen log1LT_LP=log(1+L_temp/(L-L_temp))
		gen logLT_LP=log(L_temp/(L-L_temp))
		gen log1Lo_Lr=log(1+L_hours_ext/(L_hours-L_hours_ext))
		gen logLo_Lr=log(L_hours_ext/(L_hours-L_hours_ext))
		bysort ORDINAL: egen meanm_w=mean(m_w)
		bysort ORDINAL: egen meanLT_LP=mean(LT_LP)
		gen m_w_demean=m_w-meanm_w
		gen LT_LP_demean=LT_LP-meanLT_LP

/* Table  - Estimates for Equation (6). */

		xtreg m_w log1LT_LP i.YEAR , fe vce(cluster ORDINAL)
		outreg2 using Table_tempover, excel replace ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg m_w log1LT_LP i.YEAR if temp_L>0, fe vce(cluster ORDINAL) 
		outreg2 using Table_tempover, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg m_w log1LT_LP mkt_change edshockgmmb i.YEAR , fe vce(cluster ORDINAL)
		outreg2 using Table_tempover, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg m_w log1LT_LP mkt_change edshockgmmb i.YEAR if L_temp>0, fe vce(cluster ORDINAL)
		outreg2 using Table_tempover, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)

		xtreg m_w log1Lo_Lr i.YEAR , fe vce(cluster ORDINAL)
		outreg2 using Table_tempover, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg m_w log1Lo_Lr i.YEAR if L_hours_ext>0, fe vce(cluster ORDINAL) 
		outreg2 using Table_tempover, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg m_w log1Lo_Lr mkt_change edshockgmmb i.YEAR , fe vce(cluster ORDINAL)
		outreg2 using Table_tempover, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg m_w log1Lo_Lr mkt_change edshockgmmb i.YEAR if L_hours_ext>0, fe vce(cluster ORDINAL)
		outreg2 using Table_tempover, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)

/* Table  - Regression estimates for adjustable employment on demand shocks. */

		xtreg logLT_LP ed if L_temp>0, fe vce(cluster ORDINAL)
		outreg2 using Table_tempover2, excel replace ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg logLT_LP ed edshockgmmb if L_temp>0, fe vce(cluster ORDINAL)
		outreg2 using Table_tempover2, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg logLT_LP ed edshockgmmb mkt_change if L_temp>0, fe vce(cluster ORDINAL)
		outreg2 using Table_tempover2, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)

		xtreg logLo_Lr ed if L_hours_ext>0, fe vce(cluster ORDINAL)
		outreg2 using Table_tempover2, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg logLo_Lr ed edshockgmmb if L_hours_ext>0, fe vce(cluster ORDINAL)
		outreg2 using Table_tempover2, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
		xtreg logLo_Lr ed edshockgmmb mkt_change if L_hours_ext>0, fe vce(cluster ORDINAL)
		outreg2 using Table_tempover2, excel append ctitle(`NACECLIO') side alpha(0.001, 0.01, 0.05)
